@@ -2,29 +2,29 @@
 
 from .qctests import *
 from .descentPrate import descentPrate
-from .location_at_sea import LocationAtSea, location_at_sea
-from .profile_envelop import ProfileEnvelop, profile_envelop
 from .anomaly_detection import anomaly_detection
 from .possible_speed import possible_speed
 from .morello2014 import morello2014
 from .fuzzylogic import fuzzylogic
 
+from .bin_spike import Bin_Spike, bin_spike
+from .cars_normbias import CARS_NormBias
+from .constant_cluster_size import ConstantClusterSize, constant_cluster_size
 from .cum_rate_of_change import CumRateOfChange, cum_rate_of_change
+from .deepest_pressure import DeepestPressure
+from .density_inversion import DensityInversion, densitystep
+from .digit_roll_over import DigitRollOver
 from .global_range import GlobalRange
+from .gradient import Gradient, gradient
+from .gradient_depthconditional import GradientDepthConditional
+from .location_at_sea import LocationAtSea, location_at_sea
+from .monotonic_z import MonotonicZ
+from .profile_envelop import ProfileEnvelop, profile_envelop
 from .regional_range import RegionalRange
 from .rate_of_change import RateOfChange, rate_of_change
-from .gradient import Gradient, gradient
 from .spike import Spike, spike
-from .bin_spike import Bin_Spike, bin_spike
-from .tukey53H import Tukey53H, tukey53H_norm
-from .woa_normbias import WOA_NormBias, woa_normbias
-from .cars_normbias import CARS_NormBias
-from .digit_roll_over import DigitRollOver
-from .constant_cluster_size import ConstantClusterSize, constant_cluster_size
-from .density_inversion import DensityInversion, densitystep
-from .stuck_value import StuckValue
-from .gradient_depthconditional import GradientDepthConditional
 from .spike_depthconditional import SpikeDepthConditional
+from .tukey53H import Tukey53H, tukey53H, tukey53H_norm
+from .woa_normbias import WOA_NormBias, woa_normbias
+from .stuck_value import StuckValue
 from .valid_geolocation import ValidGeolocation
-from .deepest_pressure import DeepestPressure
-from .monotonic_z import MonotonicZ
