@@ -38,6 +38,9 @@ class GlobalRange(QCCheckVar):
         maxval = self.cfg["maxval"]
 
         feature = self.data[self.varname]
+        if isinstance(feature, ma.MaskedArray):
+            feature[feature.mask] = np.nan
+            feature = feature.data
 
         flag = np.zeros(feature.shape, dtype="i1")
         flag[np.nonzero(feature < minval)] = self.flag_bad
